==> AliexpressImprove_2.2.zip: js/background.js <==
function getTrackXHRBG(attr) {
    return new Promise((resolve, reject) => {
        var ordernumber = attr.ordernumber, refresh = attr.refresh, inLS = DATA.tracks[ordernumber];
        if (inLS && !refresh) return resolve(inLS);
        var xhr = new XMLHttpRequest();
        xhr.open("GET", "https://track.aliexpress.com/logisticsdetail.htm?tradeId=" + ordernumber);
        xhr.onload = (() => {
            var tracknumber = [];
            if (/"logisticsNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"logisticsNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"interMailNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"interMailNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"lgOrderCode":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"lgOrderCode":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"realMailNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"realMailNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"mailNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"mailNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (tracknumber.length > 0) {
                tracknumber = removeDublicate(tracknumber);
                DATA.tracks[ordernumber] = tracknumber;
                saveDATA();
                return resolve(tracknumber);
            } else return resolve([]);
        });
        xhr.onerror = (error => {
            console.log(error);
            return reject("Ошибка получения страницы отслеживания");
        });
        xhr.send();
    });
}

function changeCoockeLang(domain1, domain2) {
    new Promise((resolve, reject) => {
        chrome.cookies.get({
            url: "https://aliexpress." + domain1,
            name: "aep_usuc_f"
        }, c => {
            var loc = DATA.extSetting.intl_locale.split(/\s|,|\|/);
            if (2 !== loc.length) return reject("Error split locales");
            if (!~c.value.indexOf("site=" + loc[0] + "&")) {
                c = (c = c.value.replace(/(site=.*?(&|$))/, "site=" + loc[0] + "$2")).replace(/(b_locale=.*?(&|$))/, "b_locale=" + loc[1] + "$2");
                chrome.cookies.set({
                    url: "https://aliexpress." + domain1,
                    domain: ".aliexpress." + domain2,
                    name: "aep_usuc_f",
                    value: c
                }, r => resolve(10));
            } else return resolve(1);
        });
    });
}

chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
    if (request.hasOwnProperty("getTrack")) {
        getTrackXHRBG(request.getTrack).then(r => {
            sendResponse(r);
        }).catch(error => {
            sendResponse(error);
        });
        return !0;
    }
    if (request.hasOwnProperty("changeLocale") && DATA.extSetting.intl_locale) {
        Promise.all([ changeCoockeLang("ru", "ru"), changeCoockeLang("ru", "com"), changeCoockeLang("com", "com") ]).then(v => {
            if (v[0] + v[1] + v[2] > 5) sendResponse("update"); else sendResponse("ok");
        }).catch(e => {
            console.log(e);
        });
        return !0;
    }
    return !1;
});

chrome.runtime.onInstalled.addListener(details => {
    if ("install" == details.reason) {
        if (!DATA.hasOwnProperty("setting")) DATA.setting = {
            oldDesign: !1,
            totalPrice: !0,
            breadcrumbs: !0,
            origTitle: !0,
            extSearch: !0,
            stopSlider: !0,
            tracks: !0,
            evaHide: !0,
            hideTopBannerHome: !0,
            searchWithoutLogin: !0,
            copyLinkPage: !0,
            ontime_delivery_protection: !0,
            orders: !0
        };
        if (!DATA.hasOwnProperty("extSetting")) DATA.extSetting = {
            timePrice: 500,
            timeSlider: 500,
            trackURL: "https://gdeposylka.ru/*",
            intl_locale: ""
        };
        if (!DATA.hasOwnProperty("tracks")) DATA.tracks = {};
        if (!DATA.hasOwnProperty("orders")) DATA.orders = {};
        saveDATA();
    }
    if ("update" == details.reason) {
        if (Number(details.previousVersion) <= 2) {
            DATA.setting.hideTopBannerHome = !0;
            DATA.setting.searchWithoutLogin = !0;
            DATA.setting.copyLinkPage = !0;
        }
        if (Number(details.previousVersion) <= 2.1) {
            DATA.setting.orders = !0;
            DATA.orders = {};
            DATA.extSetting.intl_locale = "";
            DATA.setting.ontime_delivery_protection = !0;
            saveDATA();
        }
        saveDATA();
    }
});

==> AliexpressImprove_2.3.zip: js/background.js <==
function getTrackXHRBG(attr) {
    return new Promise((resolve, reject) => {
        var ordernumber = attr.ordernumber, refresh = attr.refresh, inLS = DATA.tracks[ordernumber];
        if (inLS && !refresh) return resolve(inLS);
        var xhr = new XMLHttpRequest();
        xhr.open("GET", "https://track.aliexpress.com/logisticsdetail.htm?tradeId=" + ordernumber);
        xhr.onload = (() => {
            var tracknumber = [];
            if (/"logisticsNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"logisticsNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"interMailNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"interMailNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"lgOrderCode":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"lgOrderCode":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"realMailNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"realMailNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (/"mailNo":"(.*?)"/.exec(xhr.responseText)) tracknumber.push(/"mailNo":"(.*?)"/.exec(xhr.responseText)[1]);
            if (tracknumber.length > 0) {
                tracknumber = removeDublicate(tracknumber);
                DATA.tracks[ordernumber] = tracknumber;
                saveDATA();
                return resolve(tracknumber);
            } else return resolve([]);
        });
        xhr.onerror = (error => {
            console.log(error);
            return reject("Ошибка получения страницы отслеживания");
        });
        xhr.send();
    });
}

function changeCoockeLang(domain1, domain2) {
    new Promise((resolve, reject) => {
        chrome.cookies.get({
            url: "https://aliexpress." + domain1,
            name: "aep_usuc_f"
        }, c => {
            var loc = DATA.extSetting.intl_locale.split(/\s|,|\|/);
            if (2 !== loc.length) return reject("Error split locales");
            if (!~c.value.indexOf("site=" + loc[0] + "&")) {
                c = (c = c.value.replace(/(site=.*?(&|$))/, "site=" + loc[0] + "$2")).replace(/(b_locale=.*?(&|$))/, "b_locale=" + loc[1] + "$2");
                chrome.cookies.set({
                    url: "https://aliexpress." + domain1,
                    domain: ".aliexpress." + domain2,
                    name: "aep_usuc_f",
                    value: c
                }, r => resolve(10));
            } else return resolve(1);
        });
    });
}

chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
    if (request.hasOwnProperty("getTrack")) {
        getTrackXHRBG(request.getTrack).then(r => {
            sendResponse(r);
        }).catch(error => {
            sendResponse(error);
        });
        return !0;
    }
    if (request.hasOwnProperty("changeLocale") && DATA.extSetting.intl_locale) {
        Promise.all([ changeCoockeLang("ru", "ru"), changeCoockeLang("ru", "com"), changeCoockeLang("com", "com") ]).then(v => {
            if (v[0] + v[1] + v[2] > 5) sendResponse("update"); else sendResponse("ok");
        }).catch(e => {
            console.log(e);
        });
        return !0;
    }
    return !1;
});

chrome.runtime.onInstalled.addListener(details => {
    if ("install" == details.reason) {
        if (!DATA.hasOwnProperty("setting")) DATA.setting = {
            oldDesign: !1,
            totalPrice: !0,
            breadcrumbs: !0,
            origTitle: !0,
            extSearch: !0,
            stopSlider: !0,
            tracks: !0,
            evaHide: !0,
            hideTopBannerHome: !0,
            searchWithoutLogin: !0,
            copyLinkPage: !0,
            ontime_delivery_protection: !0,
            orders: !0,
            openImage: !0
        };
        if (!DATA.hasOwnProperty("extSetting")) DATA.extSetting = {
            timePrice: 500,
            timeSlider: 500,
            trackURL: "https://gdeposylka.ru/*",
            intl_locale: ""
        };
        if (!DATA.hasOwnProperty("tracks")) DATA.tracks = {};
        if (!DATA.hasOwnProperty("orders")) DATA.orders = {};
        saveDATA();
    }
    if ("update" == details.reason) {
        if (Number(details.previousVersion) <= 2) {
            DATA.setting.hideTopBannerHome = !0;
            DATA.setting.searchWithoutLogin = !0;
            DATA.setting.copyLinkPage = !0;
        }
        if (Number(details.previousVersion) <= 2.1) {
            DATA.setting.orders = !0;
            DATA.orders = {};
            DATA.extSetting.intl_locale = "";
            DATA.setting.ontime_delivery_protection = !0;
        }
        if (2.2 == Number(details.previousVersion)) if (!DATA.orders) DATA.orders = {};
        if (Number(details.previousVersion) <= 2.2) DATA.setting.openImage = !0;
        saveDATA();
    }
});
